@@ -2,16 +2,23 @@
 
 from chzzk.unofficial.api.base import AsyncUnofficialBaseService, UnofficialBaseService
 from chzzk.unofficial.api.chat import AsyncChatTokenService, ChatTokenService
-from chzzk.unofficial.api.live import AsyncLiveDetailService, LiveDetailService
+from chzzk.unofficial.api.live import (
+    AsyncLiveDetailService,
+    AsyncLiveStatusPollingService,
+    LiveDetailService,
+    LiveStatusPollingService,
+)
 from chzzk.unofficial.api.user import AsyncUserStatusService, UserStatusService
 
 __all__ = [
     "AsyncChatTokenService",
     "AsyncLiveDetailService",
+    "AsyncLiveStatusPollingService",
     "AsyncUnofficialBaseService",
     "AsyncUserStatusService",
     "ChatTokenService",
     "LiveDetailService",
+    "LiveStatusPollingService",
     "UnofficialBaseService",
     "UserStatusService",
 ]
